@@ -11,23 +11,23 @@
 
 #include <QtTest>
 
-#include <qprintdialog.h>
-#include <qwidget.h>
-#include <qtabwidget.h>
-#include <QTabBar>
+#include <KConfigGroup>
+#include <KLineEdit>
+#include <KRecentFilesAction>
+#include <QPrintDialog>
 #include <QStandardPaths>
-#include <kconfiggroup.h>
-#include <klineedit.h>
-#include <krecentfilesaction.h>
+#include <QTabBar>
+#include <QTabWidget>
+#include <qwidget.h>
 
+#include "../core/document_p.h"
+#include "../part.h"
+#include "../settings.h"
 #include "../shell/okular_main.h"
 #include "../shell/shell.h"
 #include "../shell/shellutils.h"
-#include "../core/document_p.h"
 #include "../ui/findbar.h"
 #include "../ui/presentationwidget.h"
-#include "../part.h"
-#include "../settings.h"
 #include "closedialoghelper.h"
 
 #include <sys/types.h>
@@ -37,17 +37,21 @@
 #include <process.h>
 #endif
 
-namespace Okular {
+namespace Okular
+{
 class PartTest
 {
 public:
-    Okular::Document *partDocument(Okular::Part *part) const {
+    Okular::Document *partDocument(Okular::Part *part) const
+    {
         return part->m_document;
     }
-    QWidget *presentationWidget(Okular::Part *part) const {
+    QWidget *presentationWidget(Okular::Part *part) const
+    {
         return part->m_presentationWidget;
     }
-    FindBar *findWidget(Okular::Part *part) const {
+    FindBar *findWidget(Okular::Part *part) const
+    {
         return part->m_findBar;
     }
 };
@@ -58,7 +62,11 @@ class ClosePrintDialogHelper : public QObject
     Q_OBJECT
 
 public:
-    ClosePrintDialogHelper(int expectedTab) : foundDialog(false), m_expectedTab(expectedTab) { }
+    ClosePrintDialogHelper(int expectedTab)
+        : foundDialog(false)
+        , m_expectedTab(expectedTab)
+    {
+    }
     bool foundDialog;
 
 public slots:
@@ -73,7 +81,7 @@ class MainShellTest : public QObject, public Okular::PartTest
     Q_OBJECT
 
 public:
-    static QTabWidget* tabWidget(Shell *s)
+    static QTabWidget *tabWidget(Shell *s)
     {
         return s->m_tabWidget;
     }
@@ -95,20 +103,19 @@ private slots:
     void testSessionRestore();
     void testOpenInvalidFiles_data();
     void testOpenInvalidFiles();
+    void testOpenTheSameFileSeveralTimes();
 
 private:
 };
 
-QList<Shell*> getShells()
+QList<Shell *> getShells()
 {
-    QList<Shell*> shells;
-    const QList< KMainWindow * > mainWindows = KMainWindow::memberList();
-    for ( KMainWindow* kmw : mainWindows )
-    {
-        Shell* shell = qobject_cast<Shell*>( kmw );
-        if( shell )
-        {
-            shells.append( shell );
+    QList<Shell *> shells;
+    const QList<KMainWindow *> mainWindows = KMainWindow::memberList();
+    for (KMainWindow *kmw : mainWindows) {
+        Shell *shell = qobject_cast<Shell *>(kmw);
+        if (shell) {
+            shells.append(shell);
         }
     }
     return shells;
@@ -117,9 +124,8 @@ QList<Shell*> getShells()
 Shell *findShell(Shell *ignore = nullptr)
 {
     const QWidgetList wList = QApplication::topLevelWidgets();
-    for (QWidget *widget : wList )
-    {
-        Shell *s = qobject_cast<Shell*>(widget);
+    for (QWidget *widget : wList) {
+        Shell *s = qobject_cast<Shell *>(widget);
         if (s && s != ignore)
             return s;
     }
@@ -130,13 +136,13 @@ void MainShellTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
     // Don't pollute people's okular settings
-    Okular::Settings::instance( QStringLiteral("mainshelltest") );
+    Okular::Settings::instance(QStringLiteral("mainshelltest"));
 
     // Register in bus as okular
     QDBusConnectionInterface *bus = QDBusConnection::sessionBus().interface();
-    const QString myPid = QString::number( getpid() );
-    const QString serviceName = QStringLiteral("org.kde.okular-")+ myPid;
-    QVERIFY( bus->registerService(serviceName) == QDBusConnectionInterface::ServiceRegistered );
+    const QString myPid = QString::number(getpid());
+    const QString serviceName = QStringLiteral("org.kde.okular-") + myPid;
+    QVERIFY(bus->registerService(serviceName) == QDBusConnectionInterface::ServiceRegistered);
 
     // Tell the presentationWidget and queryClose to not be annoying
     KSharedConfigPtr c = KSharedConfig::openConfig();
@@ -155,14 +161,12 @@ void MainShellTest::init()
     Okular::Settings::self()->setDefaults();
 
     // Clean docdatas
-    const QList<QUrl> urls = { QUrl::fromUserInput(QStringLiteral("file://" KDESRCDIR "data/file1.pdf"))
-                               , QUrl::fromUserInput(QStringLiteral("file://" KDESRCDIR "data/tocreload.pdf"))
-                               , QUrl::fromUserInput(QStringLiteral("file://" KDESRCDIR "data/contents.epub"))
-                             };
+    const QList<QUrl> urls = {QUrl::fromUserInput(QStringLiteral("file://" KDESRCDIR "data/file1.pdf")),
+                              QUrl::fromUserInput(QStringLiteral("file://" KDESRCDIR "data/tocreload.pdf")),
+                              QUrl::fromUserInput(QStringLiteral("file://" KDESRCDIR "data/contents.epub"))};
 
-    for (const QUrl &url : urls)
-    {
-        QFileInfo fileReadTest( url.toLocalFile() );
+    for (const QUrl &url : urls) {
+        QFileInfo fileReadTest(url.toLocalFile());
         const QString docDataPath = Okular::DocumentPrivate::docDataFileName(url, fileReadTest.size());
         QFile::remove(docDataPath);
     }
@@ -171,8 +175,7 @@ void MainShellTest::init()
 void MainShellTest::cleanup()
 {
     Shell *s;
-    while ((s = findShell()))
-    {
+    while ((s = findShell())) {
         delete s;
     }
 }
@@ -203,7 +206,7 @@ void MainShellTest::testShell_data()
     const QString optionsPage2Presentation = ShellUtils::serializeOptions(true, false, false, false, false, QStringLiteral("2"), QString());
     const QString optionsPrint = ShellUtils::serializeOptions(false, true, false, false, false, QString(), QString());
     const QString optionsUnique = ShellUtils::serializeOptions(false, false, false, true, false, QString(), QString());
-    const QString optionsFind = ShellUtils::serializeOptions(false, false, false, false ,false , QString(), QStringLiteral("si:next-testing parameters!"));
+    const QString optionsFind = ShellUtils::serializeOptions(false, false, false, false, false, QString(), QStringLiteral("si:next-testing parameters!"));
 
     QTest::newRow("just show shell") << QStringList() << QString() << false << QString() << 0u << false << false << false << 0u << false << false << QString();
     QTest::newRow("open file") << file1 << QString() << false << QString() << 0u << false << false << false << 0u << false << false << QString();
@@ -213,7 +216,7 @@ void MainShellTest::testShell_data()
     QTest::newRow("two files sequence with tabs") << file1 << QString() << true << tocReload << 0u << false << false << false << 0u << false << false << QString();
     QTest::newRow("open file page number") << contentsEpub << optionsPage2 << false << QString() << 1u << false << false << false << 0u << false << false << QString();
     QTest::newRow("open file page number and presentation") << contentsEpub << optionsPage2Presentation << false << QString() << 1u << true << false << false << 0u << false << false << QString();
-    QTest::newRow("open file find") << file1 << optionsFind << false << QString() << 0u << false << false << false << 0u << false << false << QStringLiteral("si:next-testing parameters!"); 
+    QTest::newRow("open file find") << file1 << optionsFind << false << QString() << 0u << false << false << false << 0u << false << false << QStringLiteral("si:next-testing parameters!");
     QTest::newRow("open file print") << file1 << optionsPrint << false << QString() << 0u << false << true << false << 0u << false << false << QString();
     QTest::newRow("open two files unique") << file1 << optionsUnique << false << tocReload << 0u << false << false << true << 0u << false << false << QString();
     QTest::newRow("open two files unique tabs") << file1 << optionsUnique << true << tocReload << 0u << false << false << true << 0u << false << false << QString();
@@ -243,7 +246,6 @@ void MainShellTest::testShell()
     QFETCH(bool, externalProcessExpectPrintDialog);
     QFETCH(QString, externalProcessExpectFind);
 
-
     QScopedPointer<ClosePrintDialogHelper> helper;
 
     Okular::Settings::self()->setShellOpenFileInTabs(useTabs);
@@ -259,41 +261,35 @@ void MainShellTest::testShell()
     Shell *s = findShell();
     QVERIFY(s);
 
-    if (paths.count() == 1)
-    {
+    if (paths.count() == 1) {
         QCOMPARE(s->m_tabs.count(), 1);
-        Okular::Part *part = s->findChild<Okular::Part*>();
+        Okular::Part *part = s->findChild<Okular::Part *>();
         QVERIFY(part);
         QCOMPARE(part->url().url(), QStringLiteral("file://%1").arg(paths[0]));
         QCOMPARE(partDocument(part)->currentPage(), expectedPage);
         // Testing if the bar is shown or hidden as expected
         QCOMPARE(findWidget(part)->isHidden(), externalProcessExpectFind.isEmpty());
-        QCOMPARE(findWidget(part)->findChild<KLineEdit*>()->text(), externalProcessExpectFind);
+        QCOMPARE(findWidget(part)->findChild<KLineEdit *>()->text(), externalProcessExpectFind);
         // Checking if the encryption/decryption worked
         QCOMPARE(externalProcessExpectFind, ShellUtils::find(serializedOptions));
 
-    }
-    else if (paths.count() == 2)
-    {
-        if (useTabs)
-        {
+    } else if (paths.count() == 2) {
+        if (useTabs) {
             Shell *s = findShell();
             QVERIFY(s);
-            Okular::Part *part = dynamic_cast<Okular::Part*>(s->m_tabs[0].part);
-            Okular::Part *part2 = dynamic_cast<Okular::Part*>(s->m_tabs[1].part);
+            Okular::Part *part = dynamic_cast<Okular::Part *>(s->m_tabs[0].part);
+            Okular::Part *part2 = dynamic_cast<Okular::Part *>(s->m_tabs[1].part);
             QCOMPARE(s->m_tabs.count(), 2);
             QCOMPARE(part->url().url(), QStringLiteral("file://%1").arg(paths[0]));
             QCOMPARE(part2->url().url(), QStringLiteral("file://%1").arg(paths[1]));
             QCOMPARE(partDocument(part)->currentPage(), expectedPage);
             QCOMPARE(partDocument(part2)->currentPage(), expectedPage);
-        }
-        else
-        {
+        } else {
             QSet<QString> openUrls;
             Shell *s = findShell();
             QVERIFY(s);
             QCOMPARE(s->m_tabs.count(), 1);
-            Okular::Part *part = s->findChild<Okular::Part*>();
+            Okular::Part *part = s->findChild<Okular::Part *>();
             QVERIFY(part);
             QCOMPARE(partDocument(part)->currentPage(), expectedPage);
             openUrls << part->url().url();
@@ -301,21 +297,19 @@ void MainShellTest::testShell()
             Shell *s2 = findShell(s);
             QVERIFY(s2);
             QCOMPARE(s2->m_tabs.count(), 1);
-            Okular::Part *part2 = s2->findChild<Okular::Part*>();
+            Okular::Part *part2 = s2->findChild<Okular::Part *>();
             QVERIFY(part2);
             QCOMPARE(partDocument(part2)->currentPage(), expectedPage);
             openUrls << part2->url().url();
 
-            for (const QString &path : qAsConst(paths))
-            {
+            for (const QString &path : qAsConst(paths)) {
                 QVERIFY(openUrls.contains(QStringLiteral("file://%1").arg(path)));
             }
         }
     }
 
-    if (!externalProcessPath.isEmpty())
-    {
-        Okular::Part *part = s->findChild<Okular::Part*>();
+    if (!externalProcessPath.isEmpty()) {
+        Okular::Part *part = s->findChild<Okular::Part *>();
 
         QProcess p;
         QStringList args;
@@ -332,31 +326,25 @@ void MainShellTest::testShell()
         p.waitForStarted();
         QCOMPARE(p.state(), QProcess::Running);
 
-        if (useTabs || unique)
-        {
+        if (useTabs || unique) {
             // It is attaching to us, so will eventually stop
             QTRY_COMPARE_WITH_TIMEOUT(p.state(), QProcess::NotRunning, 20000);
             QCOMPARE(p.exitStatus(), QProcess::NormalExit);
             QCOMPARE(p.exitCode(), 0);
 
-            if (unique)
-            {
+            if (unique) {
                 // It is unique so part got "overwritten"
                 QCOMPARE(s->m_tabs.count(), 1);
                 QCOMPARE(part->url().url(), QStringLiteral("file://%1").arg(externalProcessPath));
                 QCOMPARE(partDocument(part)->currentPage(), externalProcessExpectedPage);
-            }
-            else
-            {
+            } else {
                 // It is attaching to us so a second tab is there
                 QCOMPARE(s->m_tabs.count(), 2);
-                Okular::Part *part2 = dynamic_cast<Okular::Part*>(s->m_tabs[1].part);
+                Okular::Part *part2 = dynamic_cast<Okular::Part *>(s->m_tabs[1].part);
                 QCOMPARE(part2->url().url(), QStringLiteral("file://%1").arg(externalProcessPath));
                 QCOMPARE(partDocument(part2)->currentPage(), externalProcessExpectedPage);
             }
-        }
-        else
-        {
+        } else {
             QTest::qWait(750);
 
             // It opened on a new process, so it is still running, we need to kill it
@@ -371,32 +359,26 @@ void MainShellTest::testShell()
         }
     }
 
-    if (expectPresentation)
-    {
+    if (expectPresentation) {
         QCOMPARE(paths.count(), 1);
-        Okular::Part *part = s->findChild<Okular::Part*>();
+        Okular::Part *part = s->findChild<Okular::Part *>();
         QTRY_VERIFY(presentationWidget(part) != nullptr);
     }
 
-    if (externalProcessExpectPresentation)
-    {
+    if (externalProcessExpectPresentation) {
         Okular::Part *part;
-        if (unique)
-        {
+        if (unique) {
             QCOMPARE(s->m_tabs.count(), 1);
-            part = dynamic_cast<Okular::Part*>(s->m_tabs[0].part);
-        }
-        else
-        {
+            part = dynamic_cast<Okular::Part *>(s->m_tabs[0].part);
+        } else {
             QCOMPARE(s->m_tabs.count(), 2);
-            part = dynamic_cast<Okular::Part*>(s->m_tabs[1].part);
+            part = dynamic_cast<Okular::Part *>(s->m_tabs[1].part);
         }
 
         QTRY_VERIFY(presentationWidget(part) != nullptr);
     }
 
-    if (helper)
-    {
+    if (helper) {
         QVERIFY(helper->foundDialog);
     }
 }
@@ -404,7 +386,7 @@ void MainShellTest::testShell()
 void ClosePrintDialogHelper::closePrintDialog()
 {
     Shell *s = findShell();
-    QPrintDialog *dialog = s->findChild<QPrintDialog*>();
+    QPrintDialog *dialog = s->findChild<QPrintDialog *>();
     if (!dialog) {
         QTimer::singleShot(0, this, &ClosePrintDialogHelper::closePrintDialog);
         return;
@@ -441,7 +423,7 @@ void MainShellTest::testFileRemembersPagePosition()
     QCOMPARE(status, Okular::Success);
     Shell *s = findShell();
     QVERIFY(s);
-    Okular::Part *part = s->findChild<Okular::Part*>();
+    Okular::Part *part = s->findChild<Okular::Part *>();
     QVERIFY(part);
     QCOMPARE(part->url().url(), QStringLiteral("file://%1").arg(paths[0]));
     QCOMPARE(partDocument(part)->currentPage(), 0u);
@@ -450,14 +432,11 @@ void MainShellTest::testFileRemembersPagePosition()
     s->closeUrl();
     QCOMPARE(part->url().url(), QString());
 
-    if (mode == 1)
-    {
+    if (mode == 1) {
         delete s;
         status = Okular::main(paths, serializedOptions);
         QCOMPARE(status, Okular::Success);
-    }
-    else
-    {
+    } else {
         QProcess p;
         QStringList args;
         args << paths[0];
@@ -474,7 +453,7 @@ void MainShellTest::testFileRemembersPagePosition()
     }
     s = findShell();
     QVERIFY(s);
-    part = s->findChild<Okular::Part*>();
+    part = s->findChild<Okular::Part *>();
     QVERIFY(part);
     QCOMPARE(part->url().url(), QStringLiteral("file://%1").arg(paths[0]));
     QCOMPARE(partDocument(part)->currentPage(), 3u);
@@ -511,45 +490,44 @@ void MainShellTest::testSessionRestore_data()
     QTest::addColumn<bool>("useTabsOpen");
     QTest::addColumn<bool>("useTabsRestore");
 
-    QStringList oneDocPaths(QStringLiteral( KDESRCDIR "data/file1.pdf" ) );
-    QStringList twoDocPaths( oneDocPaths );
+    QStringList oneDocPaths(QStringLiteral(KDESRCDIR "data/file1.pdf"));
+    QStringList twoDocPaths(oneDocPaths);
     twoDocPaths << QStringLiteral(KDESRCDIR "data/formSamples.pdf");
 
     const QString options = ShellUtils::serializeOptions(false, false, false, false, false, QString(), QString());
 
-    QTest::newRow("1 doc, 1 window, tabs")      << oneDocPaths << options << true  << true;
-    QTest::newRow("2 docs, 1 window, tabs")     << twoDocPaths << options << true  << true;
-    QTest::newRow("2 docs, 2 windows, tabs")    << twoDocPaths << options << false << true;
+    QTest::newRow("1 doc, 1 window, tabs") << oneDocPaths << options << true << true;
+    QTest::newRow("2 docs, 1 window, tabs") << twoDocPaths << options << true << true;
+    QTest::newRow("2 docs, 2 windows, tabs") << twoDocPaths << options << false << true;
     QTest::newRow("2 docs, 2 windows, no tabs") << twoDocPaths << options << false << false;
-    QTest::newRow("2 docs, 1 window, no tabs")  << twoDocPaths << options << true  << false;
+    QTest::newRow("2 docs, 1 window, no tabs") << twoDocPaths << options << true << false;
 }
 
 void MainShellTest::testSessionRestore()
 {
-    QFETCH( QStringList, paths );
-    QFETCH( QString, options );
-    QFETCH( bool, useTabsOpen );
-    QFETCH( bool, useTabsRestore );
+    QFETCH(QStringList, paths);
+    QFETCH(QString, options);
+    QFETCH(bool, useTabsOpen);
+    QFETCH(bool, useTabsRestore);
 
-    Okular::Settings::self()->setShellOpenFileInTabs( useTabsOpen );
+    Okular::Settings::self()->setShellOpenFileInTabs(useTabsOpen);
 
-    Okular::Status status = Okular::main( paths, options );
-    QCOMPARE( status, Okular::Success );
+    Okular::Status status = Okular::main(paths, options);
+    QCOMPARE(status, Okular::Success);
 
     // Gather some information about the state
     // Verify that the correct number of windows/tabs were opened
-    QList<Shell*> shells = getShells();
-    QVERIFY( !shells.isEmpty() );
+    QList<Shell *> shells = getShells();
+    QVERIFY(!shells.isEmpty());
     int numDocs = 0;
-    for ( Shell *shell : qAsConst(shells) )
-    {
-        QVERIFY( QTest::qWaitForWindowExposed( shell ) );
+    for (Shell *shell : qAsConst(shells)) {
+        QVERIFY(QTest::qWaitForWindowExposed(shell));
         numDocs += shell->m_tabs.size();
     }
 
-    QCOMPARE( numDocs, paths.size() );
-    QCOMPARE( shells.size(), useTabsOpen ? 1 : paths.size() );
-    QTest::qWait( 100 );
+    QCOMPARE(numDocs, paths.size());
+    QCOMPARE(shells.size(), useTabsOpen ? 1 : paths.size());
+    QTest::qWait(100);
 
     // Simulate session shutdown. The actual shutdown path comes through
     // QSessionManager XSMP handlers, then KApplication::commitData/saveState,
@@ -557,14 +535,13 @@ void MainShellTest::testSessionRestore()
     // session manager, the best we can do here is to make a temporary Config
     // and call KMainWindows save functions directly.
     QTemporaryFile configFile;
-    QVERIFY( configFile.open() );
+    QVERIFY(configFile.open());
 
     int numWindows = 0;
-    {   // Scope for config so that we can reconstruct from file
-        KConfig config( configFile.fileName(), KConfig::SimpleConfig );
-        for ( Shell *shell : qAsConst(shells) )
-        {
-            shell->savePropertiesInternal( &config, ++numWindows );
+    { // Scope for config so that we can reconstruct from file
+        KConfig config(configFile.fileName(), KConfig::SimpleConfig);
+        for (Shell *shell : qAsConst(shells)) {
+            shell->savePropertiesInternal(&config, ++numWindows);
             // Windows aren't necessarily closed on shutdown, but we'll use
             // this as a way to trigger the destructor code, which is normally
             // connected to the aboutToQuit signal
@@ -575,36 +552,34 @@ void MainShellTest::testSessionRestore()
     // Wait for shells to delete themselves. QTest::qWait doesn't do deferred
     // deletions so we'll set up a full event loop to do that.
     QEventLoop eventLoop;
-    QTimer::singleShot( 100, &eventLoop, &QEventLoop::quit );
-    eventLoop.exec( QEventLoop::AllEvents );
+    QTimer::singleShot(100, &eventLoop, &QEventLoop::quit);
+    eventLoop.exec(QEventLoop::AllEvents);
     shells = getShells();
-    QVERIFY( shells.isEmpty() );
+    QVERIFY(shells.isEmpty());
 
-    Okular::Settings::self()->setShellOpenFileInTabs( useTabsRestore );
+    Okular::Settings::self()->setShellOpenFileInTabs(useTabsRestore);
 
     // Simulate session restore. We can't call KMainWindow::restore() directly
     // because it asks for info from the session manager, which doesn't know
     // about our temporary config. But the logic here mostly mirrors restore().
-    KConfig config( configFile.fileName(), KConfig::SimpleConfig );
-    for( int i = 1; i <= numWindows; ++i )
-    {
-        Shell* shell = new Shell;
-        shell->readPropertiesInternal( &config, i );
+    KConfig config(configFile.fileName(), KConfig::SimpleConfig);
+    for (int i = 1; i <= numWindows; ++i) {
+        Shell *shell = new Shell;
+        shell->readPropertiesInternal(&config, i);
         shell->show();
     }
 
     // Verify that the restore state is reasonable
     shells = getShells();
-    QVERIFY( !shells.isEmpty() );
+    QVERIFY(!shells.isEmpty());
     numDocs = 0;
-    for ( Shell* shell : qAsConst(shells) )
-    {
-        QVERIFY( QTest::qWaitForWindowExposed( shell ) );
+    for (Shell *shell : qAsConst(shells)) {
+        QVERIFY(QTest::qWaitForWindowExposed(shell));
         numDocs += shell->m_tabs.size();
     }
 
-    QCOMPARE( numDocs, paths.size() );
-    QCOMPARE( shells.size(), useTabsRestore ? numWindows : paths.size() );
+    QCOMPARE(numDocs, paths.size());
+    QCOMPARE(shells.size(), useTabsRestore ? numWindows : paths.size());
 }
 
 void MainShellTest::testOpenInvalidFiles_data()
@@ -612,23 +587,22 @@ void MainShellTest::testOpenInvalidFiles_data()
     QTest::addColumn<QList<QUrl>>("files");
     QTest::addColumn<QString>("options");
 
-    QString options = ShellUtils::serializeOptions( false, false, false, false, false, QString(), QString() );
-    QUrl validFile1 = ShellUtils::urlFromArg( QStringLiteral( KDESRCDIR "data/file1.pdf" ), ShellUtils::qfileExistFunc(), QString() );
-    QUrl validFile2 = ShellUtils::urlFromArg( QStringLiteral( KDESRCDIR "data/file2.pdf" ), ShellUtils::qfileExistFunc(), QString() );
-    QUrl invalidFile = ShellUtils::urlFromArg( QStringLiteral( KDESRCDIR "data/non-existing-doc.pdf" ), ShellUtils::qfileExistFunc(), QString() );
+    QString options = ShellUtils::serializeOptions(false, false, false, false, false, QString(), QString());
+    QUrl validFile1 = ShellUtils::urlFromArg(QStringLiteral(KDESRCDIR "data/file1.pdf"), ShellUtils::qfileExistFunc(), QString());
+    QUrl validFile2 = ShellUtils::urlFromArg(QStringLiteral(KDESRCDIR "data/file2.pdf"), ShellUtils::qfileExistFunc(), QString());
+    QUrl invalidFile = ShellUtils::urlFromArg(QStringLiteral(KDESRCDIR "data/non-existing-doc.pdf"), ShellUtils::qfileExistFunc(), QString());
 
-    QList<QUrl> firstCase { invalidFile, validFile1, validFile2 };
-    QList<QUrl> secondCase { validFile1, validFile2, invalidFile };
+    QList<QUrl> firstCase {invalidFile, validFile1, validFile2};
+    QList<QUrl> secondCase {validFile1, validFile2, invalidFile};
 
-    QTest::newRow( "opening the invalid file first" ) << firstCase << options;
-    QTest::newRow( "opening the valids file first" ) << secondCase << options;
+    QTest::newRow("opening the invalid file first") << firstCase << options;
+    QTest::newRow("opening the valids file first") << secondCase << options;
 }
 
 void MainShellTest::testOpenInvalidFiles()
 {
-    QFETCH( QList<QUrl>, files  );
-    QFETCH( QString, options  );
-
+    QFETCH(QList<QUrl>, files);
+    QFETCH(QString, options);
 
     /*
      *  The purpose of this test is to verify that when we open an invalid file, no tab is created in the
@@ -636,43 +610,74 @@ void MainShellTest::testOpenInvalidFiles()
      *
      */
 
-     Okular::Settings::self()->setShellOpenFileInTabs( true );
-     Okular::Status status = Okular::main( QStringList(), options );
-     QCOMPARE( status, Okular::Success );
+    Okular::Settings::self()->setShellOpenFileInTabs(true);
+    Okular::Status status = Okular::main(QStringList(), options);
+    QCOMPARE(status, Okular::Success);
 
-     Shell *shell = findShell();
-     QVERIFY( shell );
+    Shell *shell = findShell();
+    QVERIFY(shell);
 
-     /*
-      *  We need to make sure that the KrecentFilesAction is empty before starting, because we will also test that
-      * the file gets removed from the recent documents
-      *
-      */
-     shell->m_recent->clear();
+    /*
+     *  We need to make sure that the KrecentFilesAction is empty before starting, because we will also test that
+     * the file gets removed from the recent documents
+     *
+     */
+    shell->m_recent->clear();
 
-     QScopedPointer<TestingUtils::CloseDialogHelper> closeDialogHelper { new TestingUtils::CloseDialogHelper( QDialogButtonBox::StandardButton::Ok ) };
+    QScopedPointer<TestingUtils::CloseDialogHelper> closeDialogHelper {new TestingUtils::CloseDialogHelper(QDialogButtonBox::StandardButton::Ok)};
 
-     for (const QUrl& file: files)
-     {
-         shell->openUrl( file );
-     }
+    for (const QUrl &file : files) {
+        shell->openUrl(file);
+    }
 
-     QList<QUrl> recentFiles = shell->m_recent->urls();
+    QList<QUrl> recentFiles = shell->m_recent->urls();
 
-     QVERIFY( shell->m_tabs.size() == 2 );
-     QVERIFY( shell->m_tabWidget->tabBar()->isVisible() );
+    QVERIFY(shell->m_tabs.size() == 2);
+    QVERIFY(shell->m_tabWidget->tabBar()->isVisible());
 
-     QVERIFY( ! shell->m_tabWidget->tabIcon(0).isNull() );
-     QVERIFY( ! shell->m_tabWidget->tabIcon(1).isNull() );
+    QVERIFY(!shell->m_tabWidget->tabIcon(0).isNull());
+    QVERIFY(!shell->m_tabWidget->tabIcon(1).isNull());
 
+    QVERIFY(recentFiles.size() == 2);
+}
 
-     QVERIFY( recentFiles.size() == 2 );
+void MainShellTest::testOpenTheSameFileSeveralTimes()
+{
+    QString options = ShellUtils::serializeOptions(false, false, false, false, false, QString(), QString());
 
+    Okular::Settings::self()->setShellOpenFileInTabs(true);
+    Okular::Status status = Okular::main(QStringList(), options);
+    QCOMPARE(status, Okular::Success);
+
+    Shell *shell = findShell();
+    QVERIFY(shell);
+
+    QUrl file1 = ShellUtils::urlFromArg(QStringLiteral(KDESRCDIR "data/file1.pdf"), ShellUtils::qfileExistFunc(), QString());
+    QUrl file2 = ShellUtils::urlFromArg(QStringLiteral(KDESRCDIR "data/file2.pdf"), ShellUtils::qfileExistFunc(), QString());
+    QUrl file3 = ShellUtils::urlFromArg(QStringLiteral(KDESRCDIR "data/formattest.pdf"), ShellUtils::qfileExistFunc(), QString());
+
+    shell->openUrl(file1);
+    shell->openUrl(file2);
+    shell->openUrl(file2);
+
+    QVERIFY(shell->m_tabs.size() == 3);
+
+    Okular::Settings::self()->setSwitchToTabIfOpen(true);
+
+    shell->openUrl(file3);
+
+    shell->openUrl(file1);
+    QVERIFY(shell->m_tabWidget->currentIndex() == 0);
+
+    shell->openUrl(file3);
+    QVERIFY(shell->m_tabWidget->currentIndex() == 3);
+
+    QVERIFY(shell->m_tabs.size() == 4);
 }
 
 void MainShellTest::testMiddleButtonCloseUndo()
 {
-    const QStringList paths = { QStringLiteral(KDESRCDIR "data/file1.pdf"), QStringLiteral(KDESRCDIR "data/file2.pdf") };
+    const QStringList paths = {QStringLiteral(KDESRCDIR "data/file1.pdf"), QStringLiteral(KDESRCDIR "data/file2.pdf")};
     QString serializedOptions;
     serializedOptions = ShellUtils::serializeOptions(false, false, false, false, false, QString(), QString());
 
@@ -693,5 +698,5 @@ void MainShellTest::testMiddleButtonCloseUndo()
     QCOMPARE(s->m_tabWidget->count(), paths.size());
 }
 
-QTEST_MAIN( MainShellTest )
+QTEST_MAIN(MainShellTest)
 #include "mainshelltest.moc"
