@@ -17,17 +17,19 @@
 
 using namespace Okular;
 
-PixmapGenerationThread::PixmapGenerationThread( Generator *generator )
-    : mGenerator( generator ), mRequest( nullptr ), mCalcBoundingBox( false )
+PixmapGenerationThread::PixmapGenerationThread(Generator *generator)
+    : mGenerator(generator)
+    , mRequest(nullptr)
+    , mCalcBoundingBox(false)
 {
 }
 
-void PixmapGenerationThread::startGeneration( PixmapRequest *request, bool calcBoundingBox )
+void PixmapGenerationThread::startGeneration(PixmapRequest *request, bool calcBoundingBox)
 {
     mRequest = request;
     mCalcBoundingBox = calcBoundingBox;
 
-    start( QThread::InheritPriority );
+    start(QThread::InheritPriority);
 }
 
 void PixmapGenerationThread::endGeneration()
@@ -57,42 +59,40 @@ NormalizedRect PixmapGenerationThread::boundingBox() const
 
 void PixmapGenerationThread::run()
 {
-    if ( mRequest )
-    {
-        PixmapRequestPrivate::get(mRequest)->mResultImage = mGenerator->image( mRequest );
+    if (mRequest) {
+        PixmapRequestPrivate::get(mRequest)->mResultImage = mGenerator->image(mRequest);
 
-        if ( mCalcBoundingBox )
-            mBoundingBox = Utils::imageBoundingBox( &PixmapRequestPrivate::get(mRequest)->mResultImage );
+        if (mCalcBoundingBox)
+            mBoundingBox = Utils::imageBoundingBox(&PixmapRequestPrivate::get(mRequest)->mResultImage);
     }
 }
 
-
-TextPageGenerationThread::TextPageGenerationThread( Generator *generator )
-    : mGenerator( generator ), mTextPage( nullptr )
+TextPageGenerationThread::TextPageGenerationThread(Generator *generator)
+    : mGenerator(generator)
+    , mTextPage(nullptr)
 {
-    TextRequestPrivate *treqPriv = TextRequestPrivate::get( &mTextRequest );
+    TextRequestPrivate *treqPriv = TextRequestPrivate::get(&mTextRequest);
     treqPriv->mPage = nullptr;
     treqPriv->mShouldAbortExtraction = 0;
 }
 
 void TextPageGenerationThread::startGeneration()
 {
-    if ( page() )
-    {
-        start( QThread::InheritPriority );
+    if (page()) {
+        start(QThread::InheritPriority);
     }
 }
 
 void TextPageGenerationThread::endGeneration()
 {
-    TextRequestPrivate *treqPriv = TextRequestPrivate::get( &mTextRequest );
+    TextRequestPrivate *treqPriv = TextRequestPrivate::get(&mTextRequest);
     treqPriv->mPage = nullptr;
     treqPriv->mShouldAbortExtraction = 0;
 }
 
-void TextPageGenerationThread::setPage( Page *page )
+void TextPageGenerationThread::setPage(Page *page)
 {
-    TextRequestPrivate *treqPriv = TextRequestPrivate::get( &mTextRequest );
+    TextRequestPrivate *treqPriv = TextRequestPrivate::get(&mTextRequest);
     treqPriv->mPage = page;
     treqPriv->mShouldAbortExtraction = 0;
 }
@@ -102,7 +102,7 @@ Page *TextPageGenerationThread::page() const
     return mTextRequest.page();
 }
 
-TextPage* TextPageGenerationThread::textPage() const
+TextPage *TextPageGenerationThread::textPage() const
 {
     return mTextPage;
 }
@@ -110,9 +110,8 @@ TextPage* TextPageGenerationThread::textPage() const
 void TextPageGenerationThread::abortExtraction()
 {
     // If extraction already finished no point in aborting
-    if ( !mTextPage )
-    {
-        TextRequestPrivate *treqPriv = TextRequestPrivate::get( &mTextRequest );
+    if (!mTextPage) {
+        TextRequestPrivate *treqPriv = TextRequestPrivate::get(&mTextRequest);
         treqPriv->mShouldAbortExtraction = 1;
     }
 }
@@ -126,32 +125,29 @@ void TextPageGenerationThread::run()
 {
     mTextPage = nullptr;
 
-    Q_ASSERT ( page() );
+    Q_ASSERT(page());
 
-    mTextPage = mGenerator->textPage( &mTextRequest );
+    mTextPage = mGenerator->textPage(&mTextRequest);
 
-    if ( mTextRequest.shouldAbortExtraction() )
-    {
+    if (mTextRequest.shouldAbortExtraction()) {
         delete mTextPage;
         mTextPage = nullptr;
     }
 }
 
-
-FontExtractionThread::FontExtractionThread( Generator *generator, int pages )
-    : mGenerator( generator ), mNumOfPages( pages ), mGoOn( true )
+FontExtractionThread::FontExtractionThread(Generator *generator, int pages)
+    : mGenerator(generator)
+    , mNumOfPages(pages)
+    , mGoOn(true)
 {
 }
 
-void FontExtractionThread::startExtraction( bool async )
+void FontExtractionThread::startExtraction(bool async)
 {
-    if ( async )
-    {
+    if (async) {
         connect(this, &FontExtractionThread::finished, this, &FontExtractionThread::deleteLater);
-        start( QThread::InheritPriority );
-    }
-    else
-    {
+        start(QThread::InheritPriority);
+    } else {
         run();
         deleteLater();
     }
@@ -164,13 +160,11 @@ void FontExtractionThread::stopExtraction()
 
 void FontExtractionThread::run()
 {
-    for ( int i = -1; i < mNumOfPages && mGoOn; ++i )
-    {
-        const FontInfo::List list = mGenerator->fontsForPage( i );
-        for ( const FontInfo &fi : list )
-        {
-            emit gotFont( fi );
+    for (int i = -1; i < mNumOfPages && mGoOn; ++i) {
+        const FontInfo::List list = mGenerator->fontsForPage(i);
+        for (const FontInfo &fi : list) {
+            emit gotFont(fi);
         }
-        emit progress( i );
+        emit progress(i);
     }
 }
